@@ -223,7 +223,8 @@ def config_write(key, value):
         get_config().WriteFloat(key, float(value))
     else:
         get_config().Write(key, value)
-    get_config().Flush()
+    if not __is_headless:
+        get_config().Flush()
 
 
 def config_exists(key):
@@ -311,12 +312,13 @@ FF_RECENTFILES = "RecentFile%d"
 STARTUPBLURB = "StartupBlurb"
 TELEMETRY = "Telemetry"
 TELEMETRY_PROMPT = "Telemetry prompt"
+CHECK_FOR_UPDATES = "CheckForUpdates"
 RECENT_FILE_COUNT = 10
 PRIMARY_OUTLINE_COLOR = "PrimaryOutlineColor"
 SECONDARY_OUTLINE_COLOR = "SecondaryOutlineColor"
 TERTIARY_OUTLINE_COLOR = "TertiaryOutlineColor"
 JVM_ERROR = "JVMError"
-PLUGIN_DIRECTORY = "PluginDirectory"
+PLUGIN_DIRECTORY = "PluginDirectoryCP4"
 SHOW_ANALYSIS_COMPLETE_DLG = "ShowAnalysisCompleteDlg"
 SHOW_EXITING_TEST_MODE_DLG = "ShowExitingTestModeDlg"
 SHOW_BAD_SIZES_DLG = "ShowBadSizesDlg"
@@ -334,6 +336,7 @@ WORKSPACE_CHOICE = "WorkspaceChoice"
 ERROR_COLOR = "ErrorColor"
 INTERPOLATION_MODE = "InterpolationMode"
 INTENSITY_MODE = "IntensityMode"
+NORMALIZATION_FACTOR = "NormalizationFactor"
 SAVE_PIPELINE_WITH_PROJECT = "SavePipelineWithProject"
 FILENAME_RE_GUESSES_FILE = "FilenameRegularExpressionGuessesFile"
 PATHNAME_RE_GUESSES_FILE = "PathnameRegularExpressionGuessesFile"
@@ -624,6 +627,12 @@ temporarily to disk (but will efficiently access OMERO image planes
 directly from the server).\
 """
 
+UPDATER_HELP = """\
+Allow CellProfiler to automatically check for and notify the user of new versions.
+If enabled, CellProfiler will check GitHub once per week for updates.\
+"""
+
+
 NORMALIZATION_FACTOR_HELP = """\
 Sets the normalization factor for intensity normalization methods:
 
@@ -1033,8 +1042,10 @@ def get_skip_version():
 
 
 def set_skip_version(ver):
+    global __is_headless
     get_config().Write(SKIPVERSION, str(ver))
-    get_config().Flush()
+    if not __is_headless:
+        get_config().Flush()
 
 
 __show_sampling = None
@@ -1051,10 +1062,11 @@ def get_show_sampling():
 
 
 def set_show_sampling(value):
-    global __show_sampling
+    global __show_sampling, __is_headless
     get_config().WriteBool(SHOW_SAMPLING, bool(value))
     __show_sampling = bool(value)
-    get_config().Flush()
+    if not __is_headless:
+        get_config().Flush()
 
 
 __recent_files: dict = {}
@@ -1099,6 +1111,10 @@ def get_plugin_directory():
         __plugin_directory = config_read(PLUGIN_DIRECTORY)
     elif get_headless():
         return None
+    elif config_exists("PluginDirectory"):
+        # Import and store directory from CP3
+        __plugin_directory = config_read("PluginDirectory")
+        set_plugin_directory(__plugin_directory)
     else:
         import wx
 
@@ -1196,8 +1212,10 @@ def get_telemetry():
 
 
 def set_telemetry(val):
+    global __is_headless
     get_config().WriteBool(TELEMETRY, val)
-    get_config().Flush()
+    if not __is_headless:
+        get_config().Flush()
 
 
 def get_telemetry_prompt():
@@ -1208,8 +1226,37 @@ def get_telemetry_prompt():
 
 
 def set_telemetry_prompt(val):
+    global __is_headless
     get_config().WriteBool(TELEMETRY_PROMPT, val)
-    get_config().Flush()
+    if not __is_headless:
+        get_config().Flush()
+
+
+def get_check_update():
+    if not config_exists(CHECK_FOR_UPDATES):
+        return "Never"
+    return get_config().Read(CHECK_FOR_UPDATES)
+
+
+def get_check_update_bool():
+    if not config_exists(CHECK_FOR_UPDATES):
+        return True
+    update_str = get_config().Read(CHECK_FOR_UPDATES)
+    if update_str == "Disabled":
+        return False
+    else:
+        return True
+
+
+def set_check_update(val):
+    if str(val) == "False":
+        val = "Disabled"
+    elif str(val) == "True":
+        val = "Never"
+    global __is_headless
+    get_config().Write(CHECK_FOR_UPDATES, val)
+    if not __is_headless:
+        get_config().Flush()
 
 
 def get_startup_blurb():
@@ -1219,8 +1266,10 @@ def get_startup_blurb():
 
 
 def set_startup_blurb(val):
+    global __is_headless
     get_config().WriteBool(STARTUPBLURB, val)
-    get_config().Flush()
+    if not __is_headless:
+        get_config().Flush()
 
 
 def get_primary_outline_color():
@@ -1479,10 +1528,11 @@ def get_max_workers():
 
 def set_max_workers(value):
     """Set the maximum number of worker processes allowed during analysis"""
-    global __max_workers
+    global __max_workers, __is_headless
     get_config().WriteInt(MAX_WORKERS, value)
     __max_workers = value
-    get_config().Flush()
+    if not __is_headless:
+        get_config().Flush()
 
 
 __temp_dir = None
@@ -1747,19 +1797,31 @@ def set_choose_image_set_frame_size(w, h):
     config_write(CHOOSE_IMAGE_SET_FRAME_SIZE, "%d,%d" % (w, h))
 
 
-__normalization_factor = "1.0"
+__normalization_factor = None
 
 
 def get_normalization_factor():
     global __normalization_factor
-
+    if __normalization_factor is not None:
+        return __normalization_factor
+    if config_exists(NORMALIZATION_FACTOR):
+        __normalization_factor = config_read(NORMALIZATION_FACTOR)
+    else:
+        __normalization_factor = "1.0"
     return __normalization_factor
 
 
 def set_normalization_factor(normalization_factor):
     global __normalization_factor
-
+    try:
+        float(normalization_factor)
+    except ValueError:
+        print(
+            f"Unable to set {NORMALIZATION_FACTOR} to {normalization_factor}, value must be a number."
+        )
+        return
     __normalization_factor = normalization_factor
+    config_write(NORMALIZATION_FACTOR, normalization_factor)
 
 
 def add_progress_callback(callback):
